Name:           libssh2
Version:        1.8.2
Release:        1
Summary:        A library implementing the SSH2 protocol

Group:          System Environment/Libraries
License:        BSD
URL:            http://www.libssh2.org/
Source0:        http://www.libssh2.org/download/%{name}-%{version}.tar.gz
Source1:        http://www.libssh2.org/download/%{name}-%{version}.tar.gz.asc
BuildRoot:      /var/tmp/%{name}-%{version}-%{release}-root

#Source100: %{name}-%{version}-%{release}.build.log

BuildRequires:  zlib-devel
BuildRequires:  pkg-config, make
BuildRequires:  libgcc >= 6.3.0-1
Requires: zlib
Requires: libgcc >= 6.3.0-1 

%description
libssh2 is a library implementing the SSH2 protocol as defined by
Internet Drafts: SECSH-TRANS(22), SECSH-USERAUTH(25),
SECSH-CONNECTION(23), SECSH-ARCH(20), SECSH-FILEXFER(06)*,
SECSH-DHGEX(04), and SECSH-NUMBERS(10).

The library is available as 32-bit and 64-bit.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%package        docs 
Summary:        Documentation for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description    docs
The %{name}-docs package contains man pages and examples for
developing applications that use %{name}.


%prep
%setup -q

rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit

%build
export RM="/usr/bin/rm -f"
export GREP="/usr/bin/grep"
export PATH="/usr/bin:$PATH"

# setup environment for 32-bit and 64-bit builds
export AR="/usr/bin/ar -X32_64"
export NM="/usr/bin/nm -X32_64"

# first build the 64-bit version
export CC="gcc -maix64 -O2"
cd 64bit
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib"
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir}64 \
    --mandir=%{_mandir} \
    --enable-shared --disable-static
gmake

# Test case ssh2.sh will fail if building with non root-user as non-root user on AIX cannot start ssh demon  

(gmake -C tests check || true )

slibclean


mv ./src/.libs/%{name}.so.1 ../32bit/

# now build the 32-bit version
export CC="gcc -maix32 -O2 -D_LARGE_FILES"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
cd ../32bit
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static
gmake

(gmake -C tests check || true )

slibclean


# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q ./src/.libs/%{name}.a ./%{name}.so.1


%install
export GREP="/usr/bin/grep "

[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

#Install on 64bit mode
export OBJECT_MODE=64
cd 64bit
gmake DESTDIR=${RPM_BUILD_ROOT} install

#Install on 32bit mode
export OBJECT_MODE=32
cd ../32bit
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}
  for dir in lib lib64 include
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/COPYING 32bit/README 32bit/NEWS
%{_libdir}/*.a
%{_libdir}64/*.a
/usr/lib/*.a
/usr/lib64/*.a


%files docs
%defattr(-,root,system,-)
%doc 32bit/COPYING 32bit/example/
%{_mandir}/man?/*


%files devel
%defattr(-,root,system,-)
%doc 32bit/COPYING 
%{_includedir}/*
%{_libdir}/*.la
/usr/include/*
/usr/lib/*.la


%changelog
* Wed May 08 2019 Ravi Hirekurabar <rhirekur@in.ibm.com> - 1.8.2-1
- Updated to 1.8.2 to fix following security vulnerability
- CVE-2019-3855 CVE-2019-3856 CVE-2019-3857 CVE-2019-3858 
- CVE-2019-3859 CVE-2019-3860 CVE-2019-3861 CVE-2019-3862 
- CVE-2019-3863

* Mon Aug 13 2018 Ravi Hirekurabar<rhirekur@in.ibm.com> - 1.8.0-3
- Rebuild modifying Requires: libgcc >= 6.3.0

* Tue May 29 2018 Ravi Hirekurabar<rhirekur@in.ibm.com> - 1.8.0-2
- Rebuild adding Requires: gcc >= 6.3.0

* Tue Jan 23 2018 Reshma V Kumar <reskumar@in.ibm.com> - 1.8.0-1
- Port for AIX

* Wed Jun 21 2017 Tony Reix <tony.reix@bull.net> - 1.8.0-1
- Fix issue with libssl.so and libcrypto.so

* Fri Oct 19 2012 Gerard Visiedo <gerard.visiedo@bull.net> - 1.4.2-1
- Update to version 1.4.2 and build on 32 and 64 bit

* Thu Mar 29 2012 Gerard Visiedo <gerard.visiedo@bull.net> - 1.2.7-2
- Port on Aix6.1

* Fri Mar 04 2011 Patricia Cugny <patricia.cugnt@bull.net> - 1.2.7-1
- first version for AIX V5.3 and higher
